emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/term/mac-win.el,v


From: YAMAMOTO Mitsuharu
Subject: [Emacs-diffs] Changes to emacs/lisp/term/mac-win.el,v
Date: Sun, 27 Aug 2006 07:08:08 +0000

CVSROOT:        /cvsroot/emacs
Module name:    emacs
Changes by:     YAMAMOTO Mitsuharu <mituharu>   06/08/27 07:08:07

Index: mac-win.el
===================================================================
RCS file: /cvsroot/emacs/emacs/lisp/term/mac-win.el,v
retrieving revision 1.76
retrieving revision 1.77
diff -u -b -r1.76 -r1.77
--- mac-win.el  28 Jun 2006 08:28:38 -0000      1.76
+++ mac-win.el  27 Aug 2006 07:08:07 -0000      1.77
@@ -1539,7 +1539,7 @@
 (put 'autosave-now       'mac-apple-event-id "asav") ; kAEAutosaveNow
 ;; kAEInternetEventClass
 (put 'get-url            'mac-apple-event-id "GURL") ; kAEGetURL
 ;; Converted HICommand events
 (put 'about              'mac-apple-event-id "abou") ; kHICommandAbout
 
 (defmacro mac-event-spec (event)
@@ -1739,7 +1739,7 @@
 
 (define-key mac-apple-event-map [internet-event get-url] 'mac-ae-get-url)
 
-(define-key mac-apple-event-map [hicommand about] 'display-splash-screen)
+(define-key mac-apple-event-map [hi-command about] 'display-splash-screen)
 
 ;;; Converted Carbon Events
 (defun mac-handle-toolbar-switch-mode (event)
@@ -2208,7 +2208,8 @@
          ;; If dropping in an ordinary window which we could use,
          ;; let dnd-open-file-other-window specify what to do.
          (progn
-           (goto-char (posn-point (event-start event)))
+           (when (not mouse-yank-at-point)
+             (goto-char (posn-point (event-start event))))
            (funcall handler window action data))
        ;; If we can't display the file here,
        ;; make a new window for it.
@@ -2561,8 +2562,8 @@
 
 ;; Initiate drag and drop
 
-(global-set-key [drag-n-drop] 'mac-dnd-handle-drag-n-drop-event)
-(global-set-key [M-drag-n-drop] 'mac-dnd-handle-drag-n-drop-event)
+(define-key special-event-map [drag-n-drop] 'mac-dnd-handle-drag-n-drop-event)
+(define-key special-event-map [M-drag-n-drop] 
'mac-dnd-handle-drag-n-drop-event)
 
 
@@ -1539,7 +1539,7 @@
 ;; kAEInternetEventClass
 (put 'get-url            'mac-apple-event-id "GURL") ; kAEGetURL
-;; Converted HICommand events
+;; Converted HI command events
 (put 'about              'mac-apple-event-id "abou") ; kHICommandAbout
 
 ;;;; Non-toolkit Scroll bars




reply via email to

[Prev in Thread] Current Thread [Next in Thread]